@@ -1,16 +1,14 @@
-package Algorithm::CheckDigits::M10_006;
+package Algorithm::CheckDigits::M10_011;
 
 use 5.006;
 use strict;
 use warnings;
 use integer;
 
-our $VERSION = '0.53';
+our $VERSION = '1.1.2';
 
 our @ISA = qw(Algorithm::CheckDigits);
 
-my @weight = ( 2,1,2,5,7,1,2,1,2,1,2,1 );
-
 sub new {
 	my $proto = shift;
 	my $type  = shift;
@@ -22,7 +20,7 @@ sub new {
 
 sub is_valid {
 	my ($self,$number) = @_;
-	if ($number =~ /^(\d{8}[A-Za-z]\d\d)(\d)$/) {
+	if ($number =~ /^(.*)([0-9])$/) {
 		return $2 == $self->_compute_checkdigit($1);
 	}
 	return ''
@@ -30,15 +28,16 @@ sub is_valid {
 
 sub complete {
 	my ($self,$number) = @_;
-	if ($number =~ /^\d{8}[A-Za-z]\d\d$/) {
-		return  $number . $self->_compute_checkdigit($number);
+	my $cd = $self->_compute_checkdigit($number);
+	if ($cd != -1) {
+		return $number . $cd;
 	}
 	return '';
 } # complete()
 
 sub basenumber {
 	my ($self,$number) = @_;
-	if ($number =~ /^(\d{8}[A-Za-z]\d\d)(\d)$/) {
+	if ($number =~ /^(.*)([0-9])$/) {
 		return $1 if ($2 == $self->_compute_checkdigit($1));
 	}
 	return '';
@@ -46,7 +45,7 @@ sub basenumber {
 
 sub checkdigit {
 	my ($self,$number) = @_;
-	if ($number =~ /^(\d{8}[A-Za-z]\d\d)(\d)$/) {
+	if ($number =~ /^(.*)([0-9])$/) {
 		return $2 if ($2 == $self->_compute_checkdigit($1));
 	}
 	return '';
@@ -55,21 +54,19 @@ sub checkdigit {
 sub _compute_checkdigit {
 	my $self   = shift;
 	my $number = shift;
-
-	if ($number =~ /^(\d{8})([A-Za-z])(\d\d)$/) {
-
-		my $lv     = sprintf("%2.2d",ord(uc($2)) - ord('A') + 1);
-		my @digits = split(//,"$1$lv$3");
-		my $sum    = 0;
-
-		for (my $i = 0; $i <= $#digits; $i++) {
-
-			my $tmp = $weight[$i] * $digits[$i];
-
-			$sum += $tmp / 10;
-			$sum += $tmp % 10
+	$number =~ s/\s//g;
+	$number =~ s/^1z//i;
+	$number =~ y/A-Za-z/2-90-90-72-90-90-7/;
+	if ($number =~ /^([0-9]*)$/) {
+		my @digits = split(//,$number);
+		my $even = 0;
+		my $sum  = 0;
+		foreach my $digit (@digits) {
+			$sum += $digit;
+			$sum += $digit if ($even);
+			$even = not $even;
 		}
-		return $sum % 10;
+		return (10 - $sum % 10) % 10;
 	}
 	return -1;
 } # _compute_checkdigit()
@@ -81,26 +78,26 @@ __END__
 
 =head1 NAME
 
-CheckDigits::M10_006 - compute check digits for Rentenversicherung (DE)
+CheckDigits::M10_011 - compute check digits UPS (US)
 
 =head1 SYNOPSIS
 
   use Algorithm::CheckDigits;
 
-  $rv = CheckDigits('rentenversicherung');
+  $ups = CheckDigits('ups');
 
-  if ($rv->is_valid('65180539W001')) {
+  if ($ups->is_valid('1Z 591580 68 55587736')) {
 	# do something
   }
 
-  $cn = $rv->complete('65180539W00');
-  # $cn = '65180539W001'
+  $cn = $ups->complete('1Z 591580 68 5558773');
+  # $cn = '1Z 591580 68 55587736'
 
-  $cd = $rv->checkdigit('65180539W001');
-  # $cd = '1'
+  $cd = $ups->checkdigit('1Z 591580 68 55587736');
+  # $cd = '6'
 
-  $bn = $rv->basenumber('65180539W001');
-  # $bn = '65180539W00'
+  $bn = $ups->basenumber('1Z 591580 68 55587736');
+  # $bn = '1Z 591580 68 5558773'
   
 =head1 DESCRIPTION
 
@@ -110,20 +107,19 @@ CheckDigits::M10_006 - compute check digits for Rentenversicherung (DE)
 
 =item 1
 
-The letter is replaced with a two-figure number appropriate to the
-position of the letter in the german alphabet.
+Beginning left all numbers are weighted alternatively 1 and 2.
 
 =item 2
 
-Beginning left all numbers are weighted with 2,1,2,5,7,1,2,1,2,1,2,1.
+The sum of all products is computed.
 
 =item 3
 
-The the total of the digits of all products is computed.
+The sum of step 3 ist taken modulo 10.
 
 =item 4
 
-The check digit is sum from step 3 taken modulo 10.
+The check digit is the difference between 10 and the number from step 3.
 
 =back
 
